@@ -1,8 +1,8 @@
 #!/usr/bin/python3
 
 from debian.copyright import License
-from lintian_brush.copyright import CopyrightUpdater, NotMachineReadableError
-from lintian_brush.fixer import report_result
+from debmutate.copyright import CopyrightEditor, NotMachineReadableError
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 
 typos = {
     'bsd-2': 'BSD-2-Clause',
@@ -33,10 +33,13 @@ def fix_shortname(copyright):
             continue
         renames[paragraph.license.synopsis] = new_name
         paragraph.license = License(new_name, paragraph.license.text)
+        fixed_lintian_tag(
+            'source', 'invalid-short-name-in-dep5-copyright',
+            info=paragraph.license.synopsis)
 
 
 try:
-    with CopyrightUpdater() as updater:
+    with CopyrightEditor() as updater:
         fix_shortname(updater.copyright)
 except (FileNotFoundError, NotMachineReadableError):
     pass
@@ -44,5 +47,4 @@ except (FileNotFoundError, NotMachineReadableError):
 report_result(
     "Fix invalid short license name in debian/copyright (%s)" % (
         ', '.join(
-            ['%s => %s' % (old, new) for (old, new) in renames.items()])),
-    fixed_lintian_tags=['invalid-short-name-in-dep5-copyright'])
+            ['%s => %s' % (old, new) for (old, new) in renames.items()])))
